@@ -90,7 +90,7 @@ pub trait V4Interaction: Interaction + Send + Sync {
   fn key(&self) -> Option<String>;
 
   /// Clones this interaction and wraps it in a box
-  fn boxed_v4(&self) -> Box<dyn V4Interaction>;
+  fn boxed_v4(&self) -> Box<dyn V4Interaction + Send + Sync>;
 
   /// Annotations and comments associated with this interaction
   fn comments(&self) -> HashMap<String, Value>;
@@ -118,6 +118,12 @@ pub trait V4Interaction: Interaction + Send + Sync {
 
   /// Set the transport used with the interaction
   fn set_transport(&mut self, transport: Option<String>);
+
+  /// Creates a new version with a calculated key
+  fn with_unique_key(&self) -> Box<dyn V4Interaction + Send + Sync>;
+
+  /// Returns the current key if set, otherwise calculates a new one
+  fn unique_key(&self) -> String;
 }
 
 impl Display for dyn V4Interaction {
@@ -134,7 +140,7 @@ impl Display for dyn V4Interaction {
   }
 }
 
-impl Clone for Box<dyn V4Interaction> {
+impl Clone for Box<dyn V4Interaction + Send + Sync> {
   fn clone(&self) -> Self {
     if let Some(http) = self.as_v4_http() {
       Box::new(http)
@@ -148,7 +154,7 @@ impl Clone for Box<dyn V4Interaction> {
   }
 }
 
-impl PartialEq for Box<dyn V4Interaction> {
+impl PartialEq for Box<dyn V4Interaction + Send + Sync> {
   fn eq(&self, other: &Self) -> bool {
     if let Some(http) = self.as_v4_http() {
       if let Some(other) = other.as_v4_http() {
@@ -175,7 +181,7 @@ impl PartialEq for Box<dyn V4Interaction> {
 }
 
 /// Load V4 format interactions from JSON struct
-pub fn interactions_from_json(json: &Value, source: &str) -> Vec<Box<dyn V4Interaction>> {
+pub fn interactions_from_json(json: &Value, source: &str) -> Vec<Box<dyn V4Interaction + Send + Sync>> {
   match json.get("interactions") {
     Some(Value::Array(ref array)) => {
       array.iter().enumerate().map(|(index, ijson)| {
@@ -188,7 +194,7 @@ pub fn interactions_from_json(json: &Value, source: &str) -> Vec<Box<dyn V4Inter
 }
 
 /// Create an interaction from a JSON struct
-pub fn interaction_from_json(source: &str, index: usize, ijson: &Value) -> anyhow::Result<Box<dyn V4Interaction>> {
+pub fn interaction_from_json(source: &str, index: usize, ijson: &Value) -> anyhow::Result<Box<dyn V4Interaction + Send + Sync>> {
   match ijson.get("type") {
     Some(i_type) => match FromStr::from_str(json_to_string(i_type).as_str()) {
       Ok(i_type) => {
