@@ -207,7 +207,7 @@ impl V4Interaction for SynchronousMessage {
     self.key.clone()
   }
 
-  fn boxed_v4(&self) -> Box<dyn V4Interaction> {
+  fn boxed_v4(&self) -> Box<dyn V4Interaction + Send + Sync> {
     Box::new(self.clone())
   }
 
@@ -246,6 +246,17 @@ impl V4Interaction for SynchronousMessage {
   fn set_transport(&mut self, transport: Option<String>) {
     self.transport = transport.clone();
   }
+
+  fn with_unique_key(&self) -> Box<dyn V4Interaction + Send + Sync> {
+    Box::new(self.with_key())
+  }
+
+  fn unique_key(&self) -> String {
+    match &self.key {
+      None => self.calc_hash(),
+      Some(key) => key.clone()
+    }
+  }
 }
 
 impl Interaction for SynchronousMessage {
@@ -309,7 +320,7 @@ impl Interaction for SynchronousMessage {
     true
   }
 
-  fn as_v4(&self) -> Option<Box<dyn V4Interaction>> {
+  fn as_v4(&self) -> Option<Box<dyn V4Interaction + Send + Sync>> {
     Some(self.boxed_v4())
   }
 
